@@ -7,6 +7,7 @@ use 'GFX-Tools-Buffer::matrix';
 sub new {
     my ($class, $x, $y, $width, $height) = @_;
 
+    ### xy offsets are set in the 'selectArea' method
     $self = { x => $x, y => $y, width => $width, height => $height,
 	      areas => undef, };
 
@@ -15,8 +16,13 @@ sub new {
 };
 
 sub selectArea {
-  my ($self, $bitmapmatrixobj, $matrixareaobj) = @_;
+  my ($self, $xoffset, $yoffset, $width, $height, $bitmapmatrixobj, $matrixareaobj) = @_;
 
+  my $self->{x} = $xoffset;
+  my $self->{y} = $yoffset;
+  my $self->{width} = $width;
+  my $self->{height} = $height;
+  
   my $matrix = $bitmapmatrixobj->getMatrix;
   my $resultmatrix = matrix->new($self->{height}, $self->{width});
 
