@@ -25,7 +25,7 @@ sub addSelectedArea {
 
 ### override ->
 sub selectArea {
-  my ($self, $bitmapmatrixobj, $matrixareaobj) = @_;
+  my ($self, $xoffset, $yoffset, $width, $height, $bitmapmatrixobj, $matrixareaobj) = @_;
   
   return undef;
 }
